@@ -13,6 +13,7 @@
 #    under the License.
 
 import sys
+import textwrap
 
 import fixtures
 import mock
@@ -151,6 +152,10 @@ class GeneratorTestCase(base.BaseTestCase):
         'list_opt': cfg.ListOpt('list_opt',
                                 default=['1', '2', '3'],
                                 help='a list'),
+        'list_opt_with_bounds': cfg.ListOpt('list_opt_with_bounds',
+                                            default=['1', '2', '3'],
+                                            help='a list',
+                                            bounds=True),
         'list_opt_single': cfg.ListOpt('list_opt_single',
                                        default='1',
                                        help='a list'),
@@ -630,6 +635,17 @@ class GeneratorTestCase(base.BaseTestCase):
 
 # a list (list value)
 #list_opt = 1,2,3
+''')),
+        ('list_opt_with_bounds',
+         dict(opts=[('test', [(None, [opts['list_opt_with_bounds']])])],
+              expected='''[DEFAULT]
+
+#
+# From test
+#
+
+# a list (list value)
+#list_opt_with_bounds = [1,2,3]
 ''')),
         ('list_opt_single',
          dict(opts=[('test', [(None, [opts['list_opt_single']])])],
@@ -1783,5 +1799,31 @@ class AdvancedOptionsTestCase(base.BaseTestCase):
         self.assertEqual(expected, actual)
 
 
+class HostAddressTestCase(base.BaseTestCase):
+
+    opts = [cfg.HostAddressOpt('foo', help='foo option', default='0.0.0.0')]
+
+    def test_host_address(self):
+
+        config = [("namespace", [("alpha", self.opts)])]
+        groups = generator._get_groups(config)
+
+        out = moves.StringIO()
+        formatter = generator._OptFormatter(output_file=out)
+        generator._output_opts(formatter, 'alpha', groups.pop('alpha'))
+        result = out.getvalue()
+
+        expected = textwrap.dedent('''
+        [alpha]
+
+        #
+        # From namespace
+        #
+
+        # foo option (host address value)
+        #foo = 0.0.0.0
+        ''').lstrip()
+        self.assertEqual(expected, result)
+
 GeneratorTestCase.generate_scenarios()
 MachineReadableGeneratorTestCase.generate_scenarios()
